@@ -1,6 +1,23 @@
-/* Copyright Benjamin Berg 2007
+/* gtk-engines - a collection of drawing engines for GTK+ 
+ * Copyright (C) 2007 Benjamin Berg <benjamin@sipsolutions.net>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  * 
- * Released under the Terms of the GPL. */
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
+ *
+ */
 
 
 #include <gtk/gtk.h>
@@ -18,7 +35,9 @@ typedef enum {
 	WIDGET_PROGRESS_BAR,
 	WIDGET_MENUBAR,
 	WIDGET_MENUBAR_ITEM,
+#ifndef GTK_DISABLE_DEPRECATED
 	WIDGET_OPTION_MENU,
+#endif /* GTK_DISABLE_DEPRECATED */
 	WIDGET_TOOLBAR,
 	WIDGET_DEFAULT_BUTTON
 } WidgetType;
@@ -43,7 +62,9 @@ widget_type_get_type (void)
 			{ WIDGET_PROGRESS_BAR, "WIDGET_PROGRESS_BAR", "GtkProgessBar" },
 			{ WIDGET_MENUBAR, "WIDGET_MENUBAR", "GtkMenubar" },
 			{ WIDGET_MENUBAR_ITEM, "WIDGET_MENUBAR_ITEM", "GtkMenubar-item" },
+#ifndef GTK_DISABLE_DEPRECATED
 			{ WIDGET_OPTION_MENU, "WIDGET_OPTION_MENU", "GtkOptionMenu" },
+#endif
 			{ WIDGET_TOOLBAR, "WIDGET_TOOLBAR", "GtkToolbar" },
 			{ WIDGET_DEFAULT_BUTTON, "WIDGET_DEFAULT_BUTTON", "GtkButton-has-default" },
 			{ 0, NULL, NULL }
@@ -130,7 +151,7 @@ typedef struct {
 #define CHECK_AND_RADIO_DETAILS "NULL:cellcheck:cellradio:check:checkbutton:radiobutton"
 #define EXPANDER_DETAILS "NULL:expander" /* also in common details list ... */
 #define ARROW_DETAILS "NULL:arrow:tab:optionmenutab"
-#define COMMON_DETAILS "NULL:arrow:bar:base:button:buttondefault:combo_entry_button:dockitem:dockitem_bin:entry:entry_bg:frame:handle:handlebox:handlebox_bin:hpaned:hruler:hscale:hscrollbar:hseparator:label:menu:menubar:menuitem:metacity:notebook:option:optionmenu:optionmenutab:paned:scrolled_window:slider:spinbutton:spinbutton_arrow:spinbutton_down:spinbutton_up:stepper:tab:text:togglebutton:togglebuttondefault:toolbar:tooltip:treeitem:treeview:trough:viewport:viewportbin:vpaned:vruler:vscale:vscrollbar:vseparator:expander:iconview-drop-indicator:icon_view_item:icon_view"
+#define COMMON_DETAILS "NULL:arrow:bar:base:button:buttondefault:combo_entry_button:dockitem:dockitem_bin:entry:entry_bg:frame:handle:handlebox:handlebox_bin:hpaned:hruler:hscale:hscrollbar:hseparator:label:menu:menubar:menuitem:metacity:notebook:option:optionmenu:optionmenutab:paned:scrolled_window:slider:spinbutton:spinbutton_arrow:spinbutton_down:spinbutton_up:stepper:tab:text:togglebutton:togglebuttondefault:toolbar:tooltip:treeitem:treeview:trough:viewport:viewportbin:vpaned:vruler:vscale:vscrollbar:vseparator:expander:iconview-drop-indicator:icon_view_item:icon_view:entry-progress"
 
 /* The following explicitly does not test EVERY combination, as that would be
  * overkill, and would take a lot longer. */
@@ -143,7 +164,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		ARROW_ALL,
 		FILL_ALL,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -169,7 +190,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		EXPANDER_ALL,
 		GDK_WINDOW_EDGE_SOUTH
@@ -182,7 +203,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		ORIENTATION_ALL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -195,7 +216,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		EDGE_ALL
@@ -208,7 +229,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -221,7 +242,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -234,7 +255,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -253,7 +274,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -266,7 +287,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -279,7 +300,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -292,7 +313,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -305,7 +326,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -318,7 +339,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -331,7 +352,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -344,7 +365,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -357,7 +378,21 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
+		GTK_ORIENTATION_HORIZONTAL,
+		GTK_EXPANDER_EXPANDED,
+		GDK_WINDOW_EDGE_SOUTH
+	},
+#ifndef GTK_DISABLE_DEPRECATED
+	{
+		FUNCTION_BOX,
+		WIDGET_OPTION_MENU,
+		"NULL:optionmenu",
+		STATE_ALL,
+		SHADOW_ALL,
+		GTK_ARROW_UP,
+		TRUE,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -370,24 +405,12 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
-		GTK_ORIENTATION_HORIZONTAL,
-		GTK_EXPANDER_EXPANDED,
-		GDK_WINDOW_EDGE_SOUTH
-	},
-	{
-		FUNCTION_BOX,
-		WIDGET_OPTION_MENU,
-		"NULL:optionmenu",
-		STATE_ALL,
-		SHADOW_ALL,
-		GTK_ARROW_UP,
-		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
 	},
+#endif /* GTK_DISABLE_DEPRECATED */
 	{
 		FUNCTION_BOX,
 		WIDGET_TOOLBAR,
@@ -396,7 +419,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -634,7 +657,11 @@ create_testwidgets ()
 	widgets[WIDGET_MENUBAR] = gtk_menu_bar_new ();
 	widgets[WIDGET_MENUBAR_ITEM] = gtk_menu_item_new_with_label ("blah");
 	gtk_menu_shell_append (GTK_MENU_SHELL (widgets[WIDGET_MENUBAR]), widgets[WIDGET_MENUBAR_ITEM]);
+#ifndef GTK_DISABLE_DEPRECATED
 	widgets[WIDGET_OPTION_MENU] = gtk_option_menu_new ();
+#else
+#warning Not testing engines against GtkOptionMenu
+#endif /* GTK_DISABLE_DEPRECATED */
 	widgets[WIDGET_TOOLBAR] = gtk_toolbar_new ();
 	widgets[WIDGET_DEFAULT_BUTTON] = gtk_button_new_with_label ("blah");
 	/* nasty but *shrug* */
